import click
import requests
import json

@click.command()
@click.option("--api-key", help="Your api key for ChatGPT")
@click.option("--prompt", prompt="What can I do for you today?", help="Write a function in Python to find even numbers")
@click.option("--file", help="File to write ChatGPT response to")
@click.option("--max-tokens", default=7, help="The maximum number of tokens to generate in the completion")
@click.option("--temperature", default=0, help="What sampling temperature to use")

def chat(api_key, prompt, file, max_tokens, temperature):
    """Make an api call to ChatGPT and write the respone to a file"""
    if api_key is None:
        raise click.ClickException("missing api key. Please pass an api key via --api-key")
    else:
        api_url = "https://api.openai.com/v1/completions"
        headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json"}
        data = {"model": "text-davinci-003", "prompt": f"{prompt}", "temperature": temperature, "max_tokens": max_tokens}

        try:
            response = requests.post(api_url, headers=headers, json=data)
        except requests.exceptions as err:
            raise click.ClickException(err)

        json_response = response.json()

        if file is None:
            click.echo(json_response["choices"][0]["text"])
        else:
            with open(file, 'w') as f:
                f.write(json_response["choices"][0]["text"])
                click.echo(json_response)
                click.echo(f"Text written to {file}")

if __name__ == '__main__':
    chat()



from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.4'
DESCRIPTION = 'AI-Chat-Tool is a tool that brings ChatGPT to the command line'
LONG_DESCRIPTION = '# AI-Chat-Tool\nAI-Chat-Tool is a tool that brings ChatGPT to the command line.\n\nTo use this tool you will need a ChatGPT api key.\n\n### Options\n- **--api-key**\n    - (required) ChatGPT api key to use to access ChatGPT.\n- **--file**\n    - (optional) File to write ChatGPT response to.\n- **--max-tokens**\n    - (optional) The maximum number of tokens to generate in the completion.\n- **--temperature**\n    - (optional) What sampling temperature to use.\n\n### Example\n- Use AI-Chat-Tool to create a Python function that checks for even numbers\n\n**CLI**\n```\nai-chat-tool --api-key=$CHATGPTKEY --file=test.py --max-tokens=2000\n```\n```\nWhat can I do for you today?: Can you create a pyhton function that checks for even numbers?\nText written to test.py\n```\n\ \n\ \nFile created by AI-Chat-Tool\ \n**test.py**\n```python\ndef check_even(number):\n    if number % 2 == 0:\n        return True\n    else:\n        return False\n```'

# Setting up
setup(
    name="ai-chat-tool",
    version=VERSION,
    author="matoval (Matthew Sandoval)",
    author_email="<matovalcode@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['click'],
    keywords=['chatgpt', 'ai', 'chat'],
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
